@@ -8,7 +8,7 @@
 getData <- function(name='GADM', download=TRUE, path='', ...) {
 	path <- .getDataPath(path)
 	if (name=='GADM') {
-		.GADM(..., download=download, path=path, version=2.8)
+		.GADM(..., download=download, path=path)
 	} else if (name=='SRTM') {
 		.SRTM(..., download=download, path=path)
 	} else if (name=='alt') {
@@ -49,40 +49,44 @@ getData <- function(name='GADM', download=TRUE, path='', ...) {
 }
 
 ccodes <- function() {
-	path <- paste(system.file(package="raster"), "/external", sep='')
-	d <- utils::read.csv(paste(path, "/countries.csv", sep=""), stringsAsFactors=FALSE, encoding="UTF-8")
-	return(as.matrix(d))
+	path <- system.file(package="raster")
+	#d <- utils::read.csv(paste(path, "/external/countries.csv", sep=""), stringsAsFactors=FALSE, encoding="UTF-8")
+	readRDS(file.path(path, "external/countries.rds"))
 }
 
 
 .getCountry <- function(country='') {
 	country <- toupper(trim(country[1]))
-#	if (.nchar(country) < 3) {
-#		stop('provide a 3 letter ISO country code')
-#	}
-	cs <- ccodes()
-	cs <- toupper(cs)
 
-	iso3 <- substr(country, 1, 3)
-	if (iso3 %in% cs[,2]) {
-		return(iso3)
-	} else {
-		iso2 <- substr(country, 1, 2)
-		if (iso2 %in% cs[,3]) {
-			i <- which(country==cs[,3])
-			return( cs[i,2] )
-		} else if (country %in% cs[,1]) {
-			i <- which(country==cs[,1])
-			return( cs[i,2] )
-		} else if (country %in% cs[,4]) {
-			i <- which(country==cs[,4])
-			return( cs[i,2] )
-		} else if (country %in% cs[,5]) {
-			i <- which(country==cs[,5])
-			return( cs[i,2] )
+	cs <- ccodes()
+	cs <- sapply(cs, toupper)
+	cs <- data.frame(cs, stringsAsFactors=FALSE)
+	nc <- nchar(country)
+
+	if (nc == 3) {
+		if (country %in% cs$ISO3) {
+			return(country)
 		} else {
-			stop('provide a valid name or 3 letter ISO country code; you can get a list with: getData("ISO3")')
+			stop('unknown country')
 		}
+	} else if (nc == 2) {
+		if (country %in% cs$ISO2) {
+			i <- which(country==cs$ISO2)
+			return( cs$ISO3[i] )
+		} else {
+			stop('unknown country')
+		}
+	} else if (country %in% cs[,1]) {
+		i <- which(country==cs[,1])
+		return( cs$ISO3[i] )
+	} else if (country %in% cs[,4]) {
+		i <- which(country==cs[,4])
+		return( cs$ISO3[i] )
+	} else if (country %in% cs[,5]) {
+		i <- which(country==cs[,5])
+		return( cs$ISO3[i] )
+	} else {
+		stop('provide a valid name name or 3 letter ISO country code; you can get a list with "ccodes()"')
 	}
 }
 
@@ -92,10 +96,10 @@ ccodes <- function() {
 	if (path=='') {
 		path <- .dataloc()
 	} else {
-		if (substr(path, .nchar(path)-1, .nchar(path)) == '//' ) {
-			p <- substr(path, 1, .nchar(path)-2)		
-		} else if (substr(path, .nchar(path), .nchar(path)) == '/'  | substr(path, .nchar(path), .nchar(path)) == '\\') {
-			p <- substr(path, 1, .nchar(path)-1)
+		if (substr(path, nchar(path)-1, nchar(path)) == '//' ) {
+			p <- substr(path, 1, nchar(path)-2)		
+		} else if (substr(path, nchar(path), nchar(path)) == '/'  | substr(path, nchar(path), nchar(path)) == '\\') {
+			p <- substr(path, 1, nchar(path)-1)
 		} else {
 			p <- path
 		}
@@ -103,32 +107,43 @@ ccodes <- function() {
 			stop('path does not exist: ', path)
 		}
 	}
-	if (substr(path, .nchar(path), .nchar(path)) != '/' & substr(path, .nchar(path), .nchar(path)) != '\\') {
+	if (substr(path, nchar(path), nchar(path)) != '/' & substr(path, nchar(path), nchar(path)) != '\\') {
 		path <- paste(path, "/", sep="")
 	}
 	return(path)
 }
 
 
-.GADM <- function(country, level, download, path, version) {
+.GADM <- function(country, level, download, path, version=3.6, type='sp') {
 #	if (!file.exists(path)) {  dir.create(path, recursive=T)  }
 
 	country <- .getCountry(country)
 	if (missing(level)) {
 		stop('provide a "level=" argument; levels can be 0, 1, or 2 for most countries, and higher for some')
 	}
+
+	if (version > 3) {
+		if (type == 'sf') {
+			filename <- file.path(path, paste0('gadm36_', country, '_', level, "_sf.rds"))
+		} else {
+			filename <- file.path(path, paste0('gadm36_', country, '_', level, "_sp.rds"))
+		}
+	} else {
+		filename <- paste(path, 'GADM_', version, '_', country, '_', level, ".rds", sep="")	
+	}
 	
-	filename <- paste(path, 'GADM_', version, '_', country, '_adm', level, ".rds", sep="")
 	if (!file.exists(filename)) {
 		if (download) {
-		
-			baseurl <- paste0("http://biogeo.ucdavis.edu/data/gadm", version)
-			if (version == 2) {
-				theurl <- paste(baseurl, '/R/', country, '_adm', level, ".RData", sep="")
-			} else {
+			baseurl <- paste0("https://biogeo.ucdavis.edu/data/gadm", version)
+			if (version == 2.8) {
 				theurl <- paste(baseurl, '/rds/', country, '_adm', level, ".rds", sep="")			
+			} else {
+				if (type == 'sf') {
+					theurl <- paste(baseurl, '/Rsf/gadm36_', country, '_', level, "_sf.rds", sep="")			
+				} else {
+					theurl <- paste(baseurl, '/Rsp/gadm36_', country, '_', level, "_sp.rds", sep="")			
+				}
 			}
-			
 			.download(theurl, filename)
 			if (!file.exists(filename))	{ 
 				message("\nCould not download file -- perhaps it does not exist") 
@@ -138,13 +153,7 @@ ccodes <- function() {
 		}
 	}	
 	if (file.exists(filename)) {
-		if (version == 2) {
-			thisenvir <- new.env()
-			data <- get(load(filename, thisenvir), thisenvir)
-		} else {
-			data <- readRDS(filename)
-		}
-		return(data)
+		return(readRDS(filename))
 	} else {
 		return(NULL)
 	}
@@ -158,7 +167,7 @@ ccodes <- function() {
 	filename <- paste(path, 'countries.RData', sep="")
 	if (!file.exists(filename)) {
 		if (download) {
-			theurl <- paste("http://biogeo.ucdavis.edu/data/gadm2.6/countries_gadm26.rds", sep="")
+			theurl <- paste("https://biogeo.ucdavis.edu/data/gadm2.6/countries_gadm26.rds", sep="")
 			.download(theurl, filename)
 			if (!file.exists(filename)) {
 				message("\nCould not download file -- perhaps it does not exist") 
@@ -201,7 +210,10 @@ ccodes <- function() {
 	stopifnot(rcp %in% rcps)
 	stopifnot(year %in% c(50, 70))
 	
-	m <- matrix(c(0,1,1,0,1,1,1,1,1,1,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,0,0,1,0,1,1,1,0,0,1,1,1,1,0,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1), ncol=4)
+	#m <- matrix(c(0,1,1,0,1,1,1,1,1,1,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,0,0,1,0,1,1,1,0,0,1,1,1,1,0,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1), ncol=4)
+	
+	m <- matrix(c(0,1,1,0,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,0,0,0,1,1,1,0,1,0,1,1,1,1,0,1,1,1,1,1,0,1,1,0,1,1,1,1,1,1,1,1,1,1,1,1), ncol=4)
+
 	i <- m[which(model==models), which(rcp==rcps)]
 	if (!i) {
 		warning('this combination of rcp and model is not available')
@@ -212,7 +224,7 @@ ccodes <- function() {
 	dir.create(path, recursive=TRUE, showWarnings=FALSE)
 
 	zip <- tolower(paste(model, rcp, var, year, '.zip', sep=''))
-	theurl <- paste('http://biogeo.ucdavis.edu/data/climate/cmip5/', res, '/', zip, sep='')
+	theurl <- paste('https://biogeo.ucdavis.edu/data/climate/cmip5/', res, '/', zip, sep='')
 
 	zipfile <- paste(path, zip, sep='')
 	if (var == 'bi') {
@@ -270,7 +282,7 @@ ccodes <- function() {
 			bilfiles <- paste(var, 1:19, '_', rc, '.bil', sep='')
 			hdrfiles <- paste(var, 1:19, '_', rc, '.hdr', sep='')		
 		}
-		theurl <- paste('http://biogeo.ucdavis.edu/data/climate/worldclim/1_4/tiles/cur/', zip, sep='')
+		theurl <- paste('https://biogeo.ucdavis.edu/data/climate/worldclim/1_4/tiles/cur/', zip, sep='')
 	} else {
 		zip <- paste(var, '_', res, 'm_bil.zip', sep='')
 		zipfile <- paste(path, zip, sep='')
@@ -284,7 +296,7 @@ ccodes <- function() {
 			bilfiles <- paste(var, 1:19, '.bil', sep='')
 			hdrfiles <- paste(var, 1:19, '.hdr', sep='')	
 		}
-		theurl <- paste('http://biogeo.ucdavis.edu/data/climate/worldclim/1_4/grid/cur/', zip, sep='')
+		theurl <- paste('https://biogeo.ucdavis.edu/data/climate/worldclim/1_4/grid/cur/', zip, sep='')
 	}
 	files <- c(paste(path, bilfiles, sep=''), paste(path, hdrfiles, sep=''))
 	fc <- sum(file.exists(files))
@@ -336,7 +348,7 @@ ccodes <- function() {
 		extension(zipfilename) <- '.zip'
 		if (!file.exists(zipfilename)) {
 			if (download) {
-				theurl <- paste("http://biogeo.ucdavis.edu/data/diva/", mskpath, name, "/", country, mskname, name, ".zip", sep="")
+				theurl <- paste("https://biogeo.ucdavis.edu/data/diva/", mskpath, name, "/", country, mskname, name, ".zip", sep="")
 				.download(theurl, zipfilename)
 				if (!file.exists(zipfilename))	{ 
 					message("\nCould not download file -- perhaps it does not exist") 
@@ -355,7 +367,7 @@ ccodes <- function() {
 	} else {
 		#patrn <- paste(country, '.', mskname, name, ".grd", sep="")
 		#f <- list.files(path, pattern=patrn)
-		f <- ff[substr(ff, .nchar(ff)-3, .nchar(ff)) == '.grd']
+		f <- ff[substr(ff, nchar(ff)-3, nchar(ff)) == '.grd']
 		if (length(f)==0) {
 			warning('something went wrong')
 			return(NULL)
