@@ -106,15 +106,79 @@
 			resxy <- rbind(resxy, xy)
 		}
 	}
-	return(resxy)
+	return((resxy))
 }
 
 
 
 
 
-.polygonsToRaster <- function(p, rstr, field, fun='last', background=NA, mask=FALSE, update=FALSE, updateValue="all", getCover=FALSE, filename="", silent=TRUE, ...) {
+.polygonsToRaster <- function(p, rstr, field, fun='last', background=NA, mask=FALSE, update=FALSE, updateValue="all", getCover=FALSE, filename="", silent=TRUE, faster=TRUE, ...) {
 
+
+	npol <- length(p@polygons)
+	pvals <- .getPutVals(p, field, npol, mask)
+	putvals <- pvals[,1]
+	if (ncol(pvals) > 1) {
+		rstr@data@isfactor <- TRUE
+		rstr@data@attributes <- list(pvals)
+		if (!is.character(fun)) {
+			stop('when rasterizing multiple fields you must use "fun=first" or "fun=last"')
+		} else if (!(fun %in% c('first', 'last'))) {
+			stop('when rasterizing multiple fields you must use "fun=first" or "fun=last"')
+		}
+	}
+
+
+	if (getCover) {
+		rstr <- disaggregate(raster(rstr), 10)
+		r <- .fasterize(p, rstr, rep(1, npol), background=0) 
+		return( aggregate(r, 10, mean, na.rm=TRUE, filename=filename, ...) )
+	} 
+	
+
+	
+	### new code
+	if (is.character(fun) && (ncol(pvals) == 1) && faster) {
+
+		if (fun == "last") {
+			if (mask || update) {
+				if (mask && update) stop("either use 'mask' OR 'update'")	
+				background = NA
+				r <- .fasterize(p, rstr, pvals[,1], background) 
+				if (! hasValues(r)) {
+					if (mask) { 
+						warning('there are no values to mask')
+					} else {
+						warning('there are no values to update')
+					}
+					return(r)
+				}
+				if (mask) {
+					r <- mask(rstr, r)
+				} else {
+					if (updateValue[1]=="all") {
+						r <- cover(r, rstr)
+					} else if (updateValue[1]=="NA") {
+						r <- cover(rstr, r, ...)
+					} else if (updateValue[1]=="!NA") {
+						r <- mask(cover(r, rstr), rstr, ...)
+					} else {
+						s <- stack(r, rstr)
+						r <- overlay(rstr, r, fun=function(x,y){ i = (x %in% updateValue & !is.na(y)); x[i] <- y[i]; x }, ... )
+					}
+				}
+				return(r)
+			} else {
+				r <- .fasterize(p, rstr, pvals[,1], background, filename, ...) 
+			}
+		}
+		
+	}
+	### end new code
+
+
+	
 	leftColFromX <- function ( object, x )	{
 		colnr <- (x - xmin(object)) / xres(object)
 		i <- colnr %% 1 == 0
@@ -140,13 +204,7 @@
 		filename <- rasterTmpFile()
 	}
 	
-	if (getCover) {
-#		fun <- 'first'
-#		mask <- FALSE
-#		update <- FALSE
-#		field <- -1
-		return (.polygoncover(p, rstr, filename, ...)) 		
-	}
+
 
 	if (mask & update) { 
 		stop('use either "mask" OR "update"')
@@ -231,7 +289,7 @@
 	}
 	
 	if (! silent) { 
-		message('Found', npol, ' region(s) and ', cnt, ' polygon(s)') 
+		message('Found ', npol, ' region(s) and ', cnt, ' polygon(s)') 
 	}
 	
 	polinfo <- subset(polinfo, polinfo[,1] <= cnt, drop=FALSE)
@@ -284,10 +342,17 @@
 				
 				mypoly <- pollist[[subpol[i,1]]]
 				intersection <- .intersectLinePolygon(myline, mypoly@coords)
+				#if (nrow(intersection) %% 2 == 1) {
+				# this is a bit speculative
+				# not OK!
+				#	intersection <- unique(intersection)
+				#}
+
 				x <- sort(intersection[,1])
 				if (length(x) > 0) {
-					if ( sum(x[-length(x)] == x[-1]) > 0 ) {
-					# single node intersection going out of polygon ....
+					if ((nrow(intersection) %% 2 == 1) || ( sum(x[-length(x)] == x[-1]) > 0 )) {
+					# uneven number or duplicates
+					# e.g. single node intersection going out of polygon ....
 						spPnts <- SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
 						spPol <- SpatialPolygons(list(Polygons(list(mypoly), 1)))
 						over <- over(spPnts, spPol)
@@ -299,6 +364,7 @@
 						}
 						# print(paste('exit node intersection on row:', r))
 					} else {
+					
 						for (k in 1:round(nrow(intersection)/2)) {
 							l <- (k * 2) - 1		
 							x1 <- x[l]
@@ -318,7 +384,18 @@
 							x2a <- min(rxmx, max(rxmn, x2a))
 							col1 <- leftColFromX(rstr, x1a)
 							col2 <- rightColFromX(rstr, x2a)
-							if (col1 > col2) { next }
+							if (col1 > col2) { 
+								spPnts <- SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
+								spPol <- SpatialPolygons(list(Polygons(list(mypoly), 1)))
+								over <- over(spPnts, spPol)
+								if ( subpol[i, 5] == 1 ) {
+									holes[!is.na(over)] <- holes[!is.na(over)] - 1
+								} else {
+									rvtmp[!is.na(over)] <- subpol[i,4] 
+									holes[!is.na(over)] <- holes[!is.na(over)] + 1
+								}
+								next
+							}
 							if ( subpol[i, 5] == 1 ) {
 								holes[col1:col2] <- holes[col1:col2] - 1
 							} else {
@@ -393,13 +470,15 @@
 #plot( .polygonsToRaster(p, rstr) )
 
 
-.polygoncover <- function(p, x, filename, ...) {
+...polygoncover <- function(p, x, filename, ...) {
 	d <- disaggregate(raster(x), 10)
 	r <- .polygonsToRaster(p, d, filename=filename, field=1, fun='first', background=0, mask=FALSE, update=FALSE, getCover=FALSE, silent=TRUE, ...)
 	aggregate(r, 10, sum)
+	
+	
+	
 } 
 
-
 .Old_polygoncover <- function(rstr, filename, polinfo, lxmin, lxmax, pollist, ...) {
 # percentage cover per grid cell
 
